Outils communs

Outils communs | Table des matières

Ci-dessous une courte description de chacuns des outils.

| Met le texte sélectionné en gras.
| Met le texte sélectionné en italique.
| Souligne le texte sélectionné.
| Barre le texte sélectionné.
| Alignement à gauche.
| Alignement au centré.
| Alignement à droite.
| Texte justifié.
| Liste à puces.
| Liste numérotée
| Réduit l'indentation.
| Augmente l'indentation.
| Annule la dernière opération.
| Refait la dernière opération annulée.
| Insère ou modifie un hyperlien. Allez à la page Outil d'ajout d'hyperliens pour plus de détails.
| Efface les hyperliens qui sont sélectionées.
| Insère ou modifie une image. Allez à la page Outil d'ajout d'images pour plus de détails.
| Nettoie le code et retire les paramètres non désirés. Cet outil est très utile lorsque vous copiez du contenu provenant de logiciels de bureatique.
| Affiche cette page d'aide.
| Ouvre un éditeur permettant de modifier le code HTML.
| Insère un nouveau tableau à la position actuelle. Allez à la page Outil d'ajout de tableau pour plus de détails.
| Ajoute une ligne au tableau avant la ligne courante.
| Ajoute une ligne au tableau après la ligne courante.
| Supprime la ligne courante.
| Ajoute une colonne au tableau avant la colonne courante.
| Ajoute une colonne au tableau après la colonne courante.
| Supprime la colonne courante.
| Insère un séparateur horizontal.
| Supprime les formattages du texte sélectionné.
| Transforme le texte sélectionné en texte souscrit.
| Transforme le texte sélectionné en indice supérieur.

Aller à: Table des matières | Haut de page